@@ -227,7 +227,7 @@ sub list_regexp {
 
 
 <a href="([^"]+?/blog/show[^"]+?)">(.*?)</a>.*?
-<a href="([^"]+?)">([^"]+?)</a>.*?
+<a href="([^"]+?)"(?: rel="popup")?>([^"]+?)</a>.*?
 RE
 }
 
@@ -247,7 +247,7 @@ RE
 
 sub top_re {
     return <<'RE';
-<a href="http://frepa\.livedoor\.com/.*?/"><img src="(http://img\d+\.ico\.frepa\.livedoor\.com/member_photo/.*?\.(?:jpe?g|JPE?G|gif|GIF|png|PNG))" border="0"></a>
+<a href="http://frepa\.livedoor\.com/.*?/"(?: rel="popup")?><img src="(http://img\d+\.(?:ico\.frepa\.livedoor\.com/member_photo/|bbs\.frepa\.livedoor\.com/community_board/).*?\.(?:jpe?g|JPE?G|gif|GIF|png|PNG))" border="0"></a>
 </small>
 .*?
 <div id="namebody"><small><strong>(.*?)....</strong>
